@@ -41,39 +41,34 @@ equal to
 -- ∑ₙ xₙ.
 √N
 
-If the pyFFTW module is present, his functions are used.
-
 The transforms are always applied on the last axes for performances (C-order
 array). For more flexible usage, you must use the numpy.fft functions directly.
 
 """
 
 import logging
-import multiprocessing as mp
 from typing import Optional, Sequence, Tuple
 
 import numpy as np  # type: ignore
+import numpy.fft as npfft  # type: ignore
 from numpy import ndarray as array
 
+LIB = "numpy"
+
 try:
     import pyfftw  # type: ignore
     import pyfftw.interfaces.numpy_fft as fftw  # type: ignore
 
-    LIB = "fftw"
-    pyfftw.config.NUM_THREADS = mp.cpu_count()
+    pyfftw.config.NUM_THREADS = 4
 except ImportError:
-    LIB = "numpy"
-    logging.warning(
-        "Installation of the pyFFTW package improves performance. You can do that with `poetry install 'udft[fftw]'.`"
-    )
-    import numpy.fft as npfft  # type: ignore
+    pass
 
 
 __author__ = "François Orieux"
 __copyright__ = "2021, François Orieux <francois.orieux@universite-paris-saclay.fr>"
 __credits__ = ["François Orieux"]
 __license__ = "Public Domain"
-__version__ = "3.1.1"
+__version__ = "3.2.0"
 __maintainer__ = "François Orieux"
 __email__ = "francois.orieux@universite-paris-saclay.fr"
 __status__ = "stable"
@@ -620,3 +615,8 @@ def crandn(shape: Tuple[int, ...]) -> array:
     return np.sqrt(0.5) * (
         np.random.standard_normal(shape) + 1j * np.random.standard_normal(shape)
     )
+
+
+### Local Variables:
+### ispell-local-dictionary: "english"
+### End:
